###Install via pip:

    pip install django-tango

Or, if you want the very latest version from GitHub:

    pip install git+https://github.com/tBaxter/Tango.git

If you're installing in a fresh, brand-new virtualenvironment -- and you are using a virtualenvironment, right? -- then you'll see a lot of stuff fly by. 
Don't worry, that's just the dependencies. 
If your environment already has the usual stuff installed (Django, PIL, etc), 
then you'll speed through the Tango install. 

For more info, see the "Dependencies" section.

###For a new project, run the [Tango Starter Kit](https://github.com/tBaxter/tango-starter-kit): 

    django-admin.py startproject --template=https://github.com/tBaxter/tango-starter-kit/archive/master.zip test_project

*Note: test_project should (of course) be changed to the name of your project*